#'---
#'title: "Figure 4A: Rise in Median LFO Assessments Over Time "
#'author: "Michael Morse"
#'---
#+ message = F
rm(list = ls())
library(ggplot2)
library(dplyr)
library(stringr)

#' # Load Data
#' This anonymized data comes from our sample of Alabama circuit court cases from 1995, 2000, and 2005–11. It is limited to cases where there is a valid court action and a felony conviction. 

data <- readRDS("Data_4A2.rds")

#' Determine the median and the CI around it. We're trying to estimate the population median. I use ci.median from asbio package.
#' The problem is this package often has trouble installing on mac. Instead, I copy their function code here and use it. I modify it just in terms of what it's returning.

ci.median<-function(x, type, conf=.95){
  n<-nrow(as.matrix(x))
  if(qbinom((1-conf)/2,n,0.5)==0)stop("CI not calculable")
  L<- qbinom((1-conf)/2,n,0.5)
  U<-n-L+1
  if(L>=U)stop("CI not calculable")
  order.x<-sort(x)
  res<-list()
  res$head<-paste(paste(as.character(conf*100),"%",sep=""),c("Confidence interval for population median"))
  res$ci<-c(median=median(x),lower=order.x[L],upper=order.x[n-L+1])
  switch(type,
         "point" = res$ci[1],
         "lower" = res$ci[2],
         "upper" = res$ci[3])
}

median <-
  data %>%
  group_by(year) %>%
  summarise(pt_est = ci.median(amount.due, "point"),
            lower_bound = ci.median(amount.due, "lower"),
            upper_bound = ci.median(amount.due, "upper"))

#' # Plot

caption <- paste0("Note: This figure displays a point estimate and 95% confidence interval around the median legal financial obligations assessed each year, conditioning on cases that result in a felony conviction and are assessed more than the bail fee of $35 (n = ", nrow(data), ").")
caption <- paste0(strwrap(caption, 160), sep="", collapse="\n")

g <-
  median %>%
  ggplot(aes(x = year, y = pt_est)) +
  geom_point() +
  geom_errorbar(aes(ymin = lower_bound, ymax = upper_bound), width = .2) +
  scale_y_continuous(labels = scales::dollar_format(),
                     limits = c(0, 2500)) +
  labs(y = "Median LFOs Assessed",
       x = "Year of Court Case",
       title = "Median LFO Assessments by Year",
       caption = caption) +
  theme(plot.title = element_text(hjust = 0.5),
        plot.caption=element_text(hjust=0, margin=margin(t=15)),
        panel.background = element_blank(),
        axis.line.x =element_line(color="#2b2b2b", size=0.35),
        axis.line.y =element_line(color="#2b2b2b", size=0.35))

g
