#' ---
#' title: "Figure 4C1: Census of Governments"
#' author: "Michael Morse"
#' ---
#+ echo = F, warning = F, message = F
rm(list = ls())
library(magrittr)
library(dplyr)
library(stringr)
library(ggplot2)

#' # Load Data
#' Census of Governments Survey, 2012.

data <- read_csv("Replicate_COG_2012.txt")

#' Limit variables, rename them, and create quantities of interest. 
#+ warning = F, message = F
cog_12 <-
  data %>%
  select(year = Year4, 
         id = ID, 
         state_code = `State Code`, 
         county_code = County, 
         type_code = `Type Code`,
         name = Name, 
         fips_state = `FIPS Code-State`, 
         pop = `Population`,
         zero_data = ZeroData, 
         imputed = `Imputed Record`, 
         total_revenue = `Total Revenue`,
         total_revenue_own_sources = `Total Rev-Own Sources`,
         lfos = `Fines and Forfeits`) %>%
  mutate(lfos = lfos * 1000,
         total_revenue = total_revenue * 1000,
         total_revenue_own_sources = total_revenue_own_sources * 1000,
         lfos_per_cap = lfos / pop)

#' # Prep data

#' First, create a county dictionary from the data to be applied below. Also state dicts from 1A.R.
county_dict <- cog_12 %>% filter(type_code == 1) %>% select(state_code, county_code, name, pop)

state_name_dict <- 
  read_excel("Replicate_COG_codebook.xlsx", sheet = "state") %>% 
  mutate(state_code = str_pad(state, width = 2, side = "left", pad = "0")) %>%
  select(-state)

#' Summarise the data at the county level. This sums the survey response of the county with the survey response(s) of all the
#' localities within that same county.

county_12 <-
  cog_12 %>%
  group_by(state_code, county_code) %>%
  summarise(lfos = sum(lfos),
            total_revenue_own_sources = sum(total_revenue_own_sources)) %>%
  mutate(lfo_pct_of_own_source_rev = (lfos / total_revenue_own_sources)) %>%
  left_join(county_dict) %>%
  left_join(state_name_dict) %>%
  ungroup() %>%
  arrange(state_full) %>%
  mutate(lfos_per_cap = (lfos / pop) %>% round(digits = 2),
         county = name %>% str_to_title() %>% str_replace("County", ""))


#' # Plot

caption <- "Note: The data comes from 2012 Census of Governments: State & Local Finances, collected by the U.S. Census Bureau. Fines and forfeits (code U30) are defined as \"revenue from penalties imposed for violations of law; civil penalties (e.g., for violating court orders); court fees if levied upon conviction of a crime or violation; court-ordered restitutions to crime victims where government actually collects the monies; and forfeits of deposits held for performance guarantees or against loss or damage (such as forfeited bail and collateral).\" It excludes \"penalties relating to tax delinquency; library fines; and sale of confiscated property.\""
caption <- paste0(strwrap(caption, 155), sep="", collapse="\n")

g <-
  county_12 %>%
  filter(state_full == "Alabama",
         county_code != "000") %>%
  mutate(county_plot = factor(county, levels = county[order(lfos_per_cap)])) %>%
  ggplot(aes(x = county_plot)) +
  geom_bar(aes(y = lfos_per_cap),
           stat = "identity") +
  scale_y_continuous(labels = scales::dollar_format()) +
  labs(y = "Fines and Forfeitures per Capita",
       x = "County",
       title = "Fines and Forfeitures Across Counties in Alabama (2012)",
       caption = caption) +
  coord_flip() +
  theme(plot.title = element_text(hjust = 0.5),
        plot.caption=element_text(hjust=0, margin=margin(t=15)),
        panel.background = element_blank(),
        axis.line.x =element_line(color="#2b2b2b", size=0.35),
        axis.line.y =element_line(color="#2b2b2b", size=0.35))

g