#' ---
#' title: "Figure 4C2: Alacourt Census"
#' author: "Michael Morse"
#' ---
#+ echo = F, warning = F, message = F
rm(list = ls())
library(magrittr)
library(dplyr)
library(stringr)
library(readr)
library(ggplot2)
library(knitr)

#' # Load Alacourt data
#' This anonymized data comes from our census of all court cases that originated in Alabama district court in 2013. It is limited to misdemeanor convictions.

misdemeanor <- readRDS("Data_4C2.rds")

#' # Create statistics for plotting
#' Calculate the median amount due by county, along with the number of cases per county to map to the scale.

tbl <-
  misdemeanor %>%
  group_by(county_num, county_name) %>%
  summarise(median_amount_due = median(amount.due),
            n = n()) %>%
  ungroup()

#' # Plot

#' First, determine the ordering based on median
tbl_order <- tbl %>% arrange(median_amount_due)

#' Create a caption, and the statistics I want to include within it.

num_district <- misdemeanor %>% mutate(court = str_extract(case_num, "^[[:alpha:]]{2}")) %>% filter(court == "DC") %>% nrow()
num_circuit <- misdemeanor %>% mutate(court = str_extract(case_num, "^[[:alpha:]]{2}")) %>% filter(court == "CC") %>% nrow()

annot <-
  tbl %>%
  filter(n == max(n) | n == min(n)) %>%
  mutate(county_name_plot = factor(county_name, levels = tbl_order$county_name),
         n = format(n, big.mark = ","))

caption <- paste0("Note: This figure plots the median legal financial obligations assessed in ", format(nrow(misdemeanor), big.mark = ","), " total convictions, including ", format(num_district, big.mark = ","), " district court cases and ", format(num_circuit, big.mark = ","), " circuit court cases. Any case with a felony conviction is not included, nor is any case with less than the bail fee of $35 in assessments. Each point is scaled by the number of cases observed, from ", annot$n[2], " in ", annot$county_name_plot[2], " to ", annot$n[1], " in ", annot$county_name_plot[1], ".")
caption <- paste0(strwrap(caption, 150), sep="", collapse="\n")

#' Actual plot
g <-
  tbl %>%
  mutate(county_name_plot = factor(county_name, levels = tbl_order$county_name)) %>%
  ggplot(aes(x = county_name_plot, y = median_amount_due)) +
  geom_point(aes(size = n), show.legend = F) +
  scale_y_continuous(labels = scales::dollar_format(),
                     limits = c(0, 1250)) +
  coord_flip() +
  labs(x = "Judicial District",
       y = "Median LFOs Assessed",
       title = "Median LFO Assessments in Misdemeanor Convictions \n by Judicial District",
       caption = caption) +
  theme(plot.title = element_text(hjust = 0.5),
        plot.caption=element_text(hjust=0, margin=margin(t=15)),
        panel.background = element_blank(),
        axis.line.x =element_line(color="#2b2b2b", size=0.35),
        axis.line.y =element_line(color="#2b2b2b", size=0.35))

g


