#' ---
#' title: "Figure 4C3: Alacourt Census"
#' author: "Michael Morse"
#' ---
#+ echo = F, warning = F
#rm(list = ls())
library(magrittr)
library(dplyr)
library(stringr)
library(readr)
library(ggplot2) # need the dev version!
library(gridExtra)
library(grid)
library(scales)
library(knitr)

#' # Load Alacourt data
#' This anonymized data comes from our census of all court cases that originated in Alabama district court in 2013. It is limited to certain misdemeanor convictions.
data <- readRDS("Data_4C3.rds")
p1_data <- data$paraphenalia
p2_data <- data$weed
p3_data <- data$disorder

#' # Plot
#' One panel per crime. I re-order the data by median amount due per county.  

#' ## Panel One - Paraphenalia 
p1 <-
  p1_data %>%
  ggplot(aes(x = reorder(county_name_plot, amount.due, function(x) {quantile(x, .5)}), y = amount.due)) +
  geom_boxplot(varwidth = T, outlier.shape = NA) +
  coord_flip(ylim = c(35, 5500)) +
  scale_y_continuous(labels = scales::dollar_format()) +
  labs(y = "LFOs Assessed",
       x = "Judicial District",
       title = "Drug Paraphenalia\n 13A-012-260(C)") +
  theme(plot.title = element_text(hjust = 0.5, size = 10),
        plot.caption=element_text(hjust=0, margin=margin(t=15)),
        panel.background = element_blank(),
        axis.line.x =element_line(color="#2b2b2b", size=0.35),
        axis.line.y =element_line(color="#2b2b2b", size=0.35))

#' ## Panel Two - Marijuana Possesion 
p2 <-
  p2_data %>%
  ggplot(aes(x = reorder(county_name_plot, amount.due, function(x) {quantile(x, .5)}), y = amount.due)) +
  geom_boxplot(varwidth = T, outlier.shape = NA) +
  coord_flip(ylim = c(35, 5500)) +
  scale_y_continuous(labels = scales::dollar_format()) +
  labs(y = "LFOs Assessed",
       x = "",
       title = "Possession of Marijuana (2nd) \n (13A-012-214)") +
  theme(plot.title = element_text(hjust = 0.5, size = 10),
        plot.caption=element_text(hjust=0, margin=margin(t=15)),
        panel.background = element_blank(),
        axis.line.x =element_line(color="#2b2b2b", size=0.35),
        axis.line.y =element_line(color="#2b2b2b", size=0.35))

#' ## Panel Three - Disorderly Conduct
p3 <-
  p3_data %>%
  ggplot(aes(x = reorder(county_name_plot, amount.due, function(x) {quantile(x, .5)}), y = amount.due)) +
  geom_boxplot(varwidth = T, outlier.shape = NA) +
  geom_boxplot(varwidth = T, outlier.shape = NA) +
  coord_flip(ylim = c(35, 1600)) +
  scale_y_continuous(labels = scales::dollar_format()) +
  labs(y = "LFOs Assessed",
       x = "",
       title = "Disorderly Conduct \n (13A-011-007)") +
  theme(plot.title = element_text(hjust = 0.5, size = 10),
        plot.caption=element_text(hjust=0, margin=margin(t=15)),
        panel.background = element_blank(),
        axis.line.x =element_line(color="#2b2b2b", size=0.35),
        axis.line.y =element_line(color="#2b2b2b", size=0.35))

caption <- "Note: This figure plots the distribution of LFOs assessed in cases that result in only one conviction and are assessed more than the bail fee of $35. The box plots are scaled by the number of cases within each misdemeanor crime panel. Outliers are not shown in the figure."
caption <- paste0(strwrap(caption, 150), sep="", collapse="\n")

gridExtra::grid.arrange(p1, p2, p3, nrow = 1, widths = c(0.33, 0.33, 0.33),  bottom = grid::textGrob(caption, x = 0.125, hjust = 0, vjust=0.5, gp = gpar(fontsize = 10)))
g <- gridExtra::arrangeGrob(p1, p2, p3, nrow = 1, widths = c(0.33, 0.33, 0.33), bottom = grid::textGrob(caption, x = 0.125, hjust = 0, vjust=0.5, gp = gpar(fontsize = 10)))


#' # In-Text Statistics
#' ## Panel 1
p1_data %>%
  group_by(county_name_plot) %>%
  summarise(q25 = quantile(amount.due, 0.25),
            q75 = quantile(amount.due, 0.75)) %>%
  ungroup() %>%
  mutate(iqr = q75 - q25) %>%
  arrange(county_name_plot) %>%
  kable()

tapply(p1_data$amount.due, p1_data$county_name_plot, quantile)

#' ## Panel 2
p2_data %>%
  group_by(county_name_plot) %>%
  summarise(q25 = quantile(amount.due, 0.25),
            q75 = quantile(amount.due, 0.75)) %>%
  ungroup() %>%
  mutate(iqr = q75 - q25) %>%
  arrange(county_name_plot) %>%
  kable()

tapply(p2_data$amount.due, p2_data$county_name_plot, quantile)

#' ## Panel 3
p3_data %>%
  group_by(county_name_plot) %>%
  summarise(q25 = quantile(amount.due, 0.25),
            q75 = quantile(amount.due, 0.75)) %>%
  ungroup() %>%
  mutate(iqr = q75 - q25) %>%
  arrange(county_name_plot) %>%
  kable()

tapply(p3_data$amount.due, p3_data$county_name_plot, quantile)


